Index: /trunk/src/game/DynamicObject.cpp
===================================================================
--- /trunk/src/game/DynamicObject.cpp (revision 237)
+++ /trunk/src/game/DynamicObject.cpp (revision 238)
@@ -138,6 +138,10 @@
 {
     // Make sure the object is back to grid container for removal as farsight targets
-    // are switched to world container on creation
-    GetMap()->SwitchGridContainers(this, false);
+    // are switched to world container on creation and they are also set to active
+    if (isActive())
+    {
+        GetMap()->SwitchGridContainers(this, false);
+        setActive(false);
+    }
     SendObjectDeSpawnAnim(GetGUID());
     AddObjectToRemoveList();
